PrinterResult class

Result of a print operation for a single printer

Constructors

PrinterResult({required String printerId, required bool success, String? errorMessage, required Duration duration})
PrinterResult.fromJson(Map<String, dynamic> json)
Deserialize from JSON
factory

Properties

duration Duration
Duration of the print operation
final
errorMessage String?
Error message if print failed
final
hashCode int
The hash code for this object.
no setterinherited
printerId String
ID of the printer
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
Whether the print operation succeeded
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize to JSON
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited